Learn R Programming

NSM3 (version 1.5)

cFligPoli: Computes a critical value for the Fligner-Policello U distribution.

Description

This function computes the critical value for the Fligner-Policello U distriburion at (or typically in the "Exact" and "Monte Carlo" cases, close to) the given alpha level.

Usage

cFligPoli(alpha,m,n,method=NA,n.mc=10000)

Arguments

alpha
A numeric value between 0 and 1.
m
A numeric value indicating the size of the first data group (X).
n
A numeric value indicating the size of the second data group (Y).
method
Either "Exact", "Monte Carlo" or "Asymptotic", indicating the desired distribution. When method=NA, "Exact" will be used if the number of permutations is 10,000 or less. Otherwise, "Monte Carlo" will be used.
n.mc
If method="Monte Carlo", the number of Monte Carlo samples used to estimate the distribution. Otherwise, not used.

Value

Returns a list with "NSM3Ch5c" class containing the following components:
m
number of observations in the first data group (X)
n
number of observations in the second data group (Y)
cutoff.U
upper tail cutoff at or below user-specified alpha
true.alpha.U
true alpha level corresponding to cutoff.U (if method="Exact" or "Monte Carlo")

Examples

Run this code
##Chapter 4 example Hollander-Wolfe-Chicken##
cFligPoli(.0504,8,7)
cFligPoli(.101,8,7)

Run the code above in your browser using DataLab