Learn R Programming

NSM3 (version 1.5)

cNDWol: Function to compute a critical value for the Nemenyi, Damico-Wolfe Y distribution.

Description

This function computes the critical value for the Nemenyi, Damico-Wolfe Y distribution at (or typically in the "Exact" and "Monte Carlo" cases, close to) the given alpha level.

Usage

cNDWol(alpha,n, method=NA, n.mc=10000)

Arguments

alpha
A numeric value between 0 and 1.
n
A vector of numeric values indicating the size of each of the k data groups, with the first element indicating the treatment group size.
method
Either "Exact", "Monte Carlo" or "Asymptotic", indicating the desired distribution. When method=NA, "Exact" will be used if the number of permutations is 10,000 or less. Otherwise, "Monte Carlo" will be used.
n.mc
If method="Monte Carlo", the number of Monte Carlo samples used to estimate the distribution. Otherwise, not used.

Value

Returns a list with "NSM3Ch6MCc" class containing the following components:
n
number of observations in the k data groups
cutoff.U
upper tail cutoff at or below user-specified alpha
true.alpha.U
true alpha level corresponding to cutoff.U (if method="Exact" or "Monte Carlo")

Examples

Run this code
##Hollander-Wolfe-Chicken Example 6.8 Motivational Effect of Knowledge of Performance
cNDWol(.0554, c(6, 6, 6),"Monte Carlo")
cNDWol(.0554, c(6, 6, 6),"Monte Carlo",n.mc=25000)
cNDWol(.0371, c(6, 6, 6),"Monte Carlo")

Run the code above in your browser using DataLab