cUmbrPK:
Computes a critical value for the Mack-Wolfe Peak Known A_p distribution.
Description
This function computes the critical value for the Mack-Wolfe Peak Known A_p distribution at (or typically in the "Exact" case, close to) the given alpha level. The function generalizes Harding's (1984) algorithm to quickly generate the distribution.
Usage
cUmbrPK(alpha, n, peak=NA, method=NA, n.mc=10000)
Arguments
alpha
A numeric value between 0 and 1.
n
A vector of numeric values indicating the size of each of the k data groups.
peak
An integer representing the known peak among the data groups.
method
Either "Exact" or "Asymptotic", indicating the desired distribution. When method=NA, if sum(n)
n.mc
Not used. Only included for standardization with other critical value procedures in the NSM3 package.
Value
Returns a list with "NSM3Ch6c" class containing the following components:
n
number of observations in the k data groups
cutoff.U
upper tail cutoff at or below user-specified alpha
true.alpha.U
true alpha level corresponding to cutoff.U (if method="Exact")
References
Harding, E. F. "An efficient, minimal-storage procedure for calculating the Mann-Whitney U, generalized U and similar distributions." Applied statistics (1984): 1-6.