Learn R Programming

NSM3 (version 1.5)

pHayStonLSA: Hayter-Sone LSA

Description

Function to compute the upper tail probability of the Hayter-Stone W asymptotic distribution for a given cutoff.

Usage

pHayStonLSA(h,k,delta=.001)

Arguments

h
Cutoff used to calculate the P-value.
k
Number of groups.
delta
Defines the fineness of the grid used to calculate the asymptotic distribution of W.

Value

Returns the asymptotic upper tail P-value.

Examples

Run this code
pHayStonLSA(2.491,3)
pHayStonLSA(4.112,4)

Run the code above in your browser using DataLab