method
Either "Exact", "Monte Carlo" or "Asymptotic", indicating the desired distribution. When method=NA, "Exact" will be used if the number of permutations is 10,000 or less. Otherwise, "Monte Carlo" will be used.
n.mc
If method="Monte Carlo", the number of Monte Carlo samples used to estimate the distribution. Otherwise, not used.