cMaxCorrNor: Quantile function for the maximum of k N(0,1) random variables with common correlation rho.
Description
Uses the integrate function based on the method proposed in Gupta, Panchapakesan and Sohn (1983).
Usage
cMaxCorrNor(alpha,k,rho)
Arguments
Value
Returns the upper tail cutoff at or immediately below the user-specified alpha.
References
Gupta, Shanti S., S. Panchapakesan, and Joong K. Sohn. "On the distribution of the studentized maximum of equally correlated normal random variables." Communications in Statistics-Simulation and Computation 14.1 (1985): 103-135.